pub enum Bound<T> {
Included(T),
Excluded(T),
Unbounded,
}🔬This is a nightly-only experimental API. (
new_range_api)Expand description
An endpoint of a range of keys.
Examples
Bounds are range endpoints:
use std::ops::Bound::*;
use std::ops::RangeBounds;
assert_eq!((..100).start_bound(), Unbounded);
assert_eq!((1..12).start_bound(), Included(&1));
assert_eq!((1..12).end_bound(), Excluded(&12));Using a tuple of Bounds as an argument to BTreeMap::range.
Note that in most cases, it’s better to use range syntax (1..5) instead.
use std::collections::BTreeMap;
use std::ops::Bound::{Excluded, Included, Unbounded};
let mut map = BTreeMap::new();
map.insert(3, "a");
map.insert(5, "b");
map.insert(8, "c");
for (key, value) in map.range((Excluded(3), Included(8))) {
println!("{key}: {value}");
}
assert_eq!(Some((&3, &"a")), map.range((Unbounded, Included(5))).next());Variants
Included(T)
🔬This is a nightly-only experimental API. (
new_range_api)An inclusive bound.
Excluded(T)
🔬This is a nightly-only experimental API. (
new_range_api)An exclusive bound.
Unbounded
🔬This is a nightly-only experimental API. (
new_range_api)An infinite endpoint. Indicates that there is no bound in this direction.
Implementations
Sourceimpl<T> Bound<T>
impl<T> Bound<T>
1.65.0 (const: unstable) · Sourcepub fn as_ref(&self) -> Bound<&T>
pub fn as_ref(&self) -> Bound<&T>
Converts from &Bound<T> to Bound<&T>.
Sourcepub const fn as_mut(&mut self) -> Bound<&mut T>
🔬This is a nightly-only experimental API. (bound_as_ref)
pub const fn as_mut(&mut self) -> Bound<&mut T>
bound_as_ref)Converts from &mut Bound<T> to Bound<&mut T>.
1.77.0 · Sourcepub fn map<U, F>(self, f: F) -> Bound<U>where
F: FnOnce(T) -> U,
pub fn map<U, F>(self, f: F) -> Bound<U>where
F: FnOnce(T) -> U,
Maps a Bound<T> to a Bound<U> by applying a function to the contained value (including
both Included and Excluded), returning a Bound of the same kind.
Examples
use std::ops::Bound::*;
let bound_string = Included("Hello, World!");
assert_eq!(bound_string.map(|s| s.len()), Included(13));use std::ops::Bound;
use Bound::*;
let unbounded_string: Bound<String> = Unbounded;
assert_eq!(unbounded_string.map(|s| s.len()), Unbounded);Sourceimpl<T> Bound<&T>where
T: Copy,
impl<T> Bound<&T>where
T: Copy,
Sourcepub fn copied(self) -> Bound<T>
🔬This is a nightly-only experimental API. (bound_copied)
pub fn copied(self) -> Bound<T>
bound_copied)Map a Bound<&T> to a Bound<T> by copying the contents of the bound.
Examples
#![feature(bound_copied)]
use std::ops::Bound::*;
use std::ops::RangeBounds;
assert_eq!((1..12).start_bound(), Included(&1));
assert_eq!((1..12).start_bound().copied(), Included(1));Sourceimpl<T> Bound<&T>where
T: Clone,
impl<T> Bound<&T>where
T: Clone,
1.55.0 (const: unstable) · Sourcepub fn cloned(self) -> Bound<T>where
T: Clone,
pub fn cloned(self) -> Bound<T>where
T: Clone,
Map a Bound<&T> to a Bound<T> by cloning the contents of the bound.
Examples
use std::ops::Bound::*;
use std::ops::RangeBounds;
let a1 = String::from("a");
let (a2, a3, a4) = (a1.clone(), a1.clone(), a1.clone());
assert_eq!(Included(&a1), (a2..).start_bound());
assert_eq!(Included(a3), (a4..).start_bound().cloned());Trait Implementations
Sourceimpl<'de, T, Context> BorrowDecode<'de, Context> for Bound<T>where
T: BorrowDecode<'de, Context>,
impl<'de, T, Context> BorrowDecode<'de, Context> for Bound<T>where
T: BorrowDecode<'de, Context>,
Sourcefn borrow_decode<D>(decoder: &mut D) -> Result<Bound<T>, DecodeError>where
D: BorrowDecoder<'de, Context = Context>,
fn borrow_decode<D>(decoder: &mut D) -> Result<Bound<T>, DecodeError>where
D: BorrowDecoder<'de, Context = Context>,
Attempt to decode this type with the given BorrowDecode.
Sourceimpl<'de, T> Deserialize<'de> for Bound<T>where
T: Deserialize<'de>,
impl<'de, T> Deserialize<'de> for Bound<T>where
T: Deserialize<'de>,
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<Bound<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<Bound<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'de, T, U> DeserializeAs<'de, Bound<T>> for Bound<U>where
U: DeserializeAs<'de, T>,
impl<'de, T, U> DeserializeAs<'de, Bound<T>> for Bound<U>where
U: DeserializeAs<'de, T>,
Sourcefn deserialize_as<D>(
deserializer: D,
) -> Result<Bound<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize_as<D>(
deserializer: D,
) -> Result<Bound<T>, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer.
Sourceimpl<T> Serialize for Bound<T>where
T: Serialize,
impl<T> Serialize for Bound<T>where
T: Serialize,
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl<T, U> SerializeAs<Bound<T>> for Bound<U>where
U: SerializeAs<T>,
impl<T, U> SerializeAs<Bound<T>> for Bound<U>where
U: SerializeAs<T>,
Sourcefn serialize_as<S>(
source: &Bound<T>,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize_as<S>(
source: &Bound<T>,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer.
impl<T> Copy for Bound<T>where
T: Copy,
impl<T> Eq for Bound<T>where
T: Eq,
impl<T> StructuralPartialEq for Bound<T>