pub struct RangeToInclusive<Idx> {
pub last: Idx,
}🔬This is a nightly-only experimental API. (
new_range_api)Expand description
A range only bounded inclusively above (..=last).
The RangeToInclusive ..=last contains all values with x <= last.
It cannot serve as an Iterator because it doesn’t have a starting point.
Examples
The ..=last syntax is a RangeToInclusive:
#![feature(new_range_api)]
#![feature(new_range)]
assert_eq!((..=5), std::range::RangeToInclusive{ last: 5 });It does not have an IntoIterator implementation, so you can’t use it in a
for loop directly. This won’t compile:
ⓘ
// error[E0277]: the trait bound `std::range::RangeToInclusive<{integer}>:
// std::iter::Iterator` is not satisfied
for i in ..=5 {
// ...
}When used as a slicing index, RangeToInclusive produces a slice of all
array elements up to and including the index indicated by last.
let arr = [0, 1, 2, 3, 4];
assert_eq!(arr[ .. ], [0, 1, 2, 3, 4]);
assert_eq!(arr[ .. 3], [0, 1, 2 ]);
assert_eq!(arr[ ..=3], [0, 1, 2, 3 ]); // This is a `RangeToInclusive`
assert_eq!(arr[1.. ], [ 1, 2, 3, 4]);
assert_eq!(arr[1.. 3], [ 1, 2 ]);
assert_eq!(arr[1..=3], [ 1, 2, 3 ]);Fields
last: Idx🔬This is a nightly-only experimental API. (
new_range_api)The upper bound of the range (inclusive)
Implementations
Sourceimpl<Idx> RangeToInclusive<Idx>where
Idx: PartialOrd,
impl<Idx> RangeToInclusive<Idx>where
Idx: PartialOrd,
Sourcepub const fn contains<U>(&self, item: &U) -> bool
🔬This is a nightly-only experimental API. (new_range_api)
pub const fn contains<U>(&self, item: &U) -> bool
new_range_api)Returns true if item is contained in the range.
Examples
assert!( (..=5).contains(&-1_000_000_000));
assert!( (..=5).contains(&5));
assert!(!(..=5).contains(&6));
assert!( (..=1.0).contains(&1.0));
assert!(!(..=1.0).contains(&f32::NAN));
assert!(!(..=f32::NAN).contains(&0.5));Trait Implementations
Sourceimpl<Idx> Clone for RangeToInclusive<Idx>where
Idx: Clone,
impl<Idx> Clone for RangeToInclusive<Idx>where
Idx: Clone,
Sourcefn clone(&self) -> RangeToInclusive<Idx>
fn clone(&self) -> RangeToInclusive<Idx>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<Idx> Debug for RangeToInclusive<Idx>where
Idx: Debug,
impl<Idx> Debug for RangeToInclusive<Idx>where
Idx: Debug,
Sourceimpl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
impl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
Sourcefn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
fn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
Converts to this type from the input type.
Sourceimpl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
impl<T> From<RangeToInclusive<T>> for RangeToInclusive<T>
Sourcefn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
fn from(value: RangeToInclusive<T>) -> RangeToInclusive<T>
Converts to this type from the input type.
Sourceimpl<Idx> Hash for RangeToInclusive<Idx>where
Idx: Hash,
impl<Idx> Hash for RangeToInclusive<Idx>where
Idx: Hash,
Sourceimpl<T> IntoBounds<T> for RangeToInclusive<T>
impl<T> IntoBounds<T> for RangeToInclusive<T>
Sourceimpl<Idx> PartialEq for RangeToInclusive<Idx>where
Idx: PartialEq,
impl<Idx> PartialEq for RangeToInclusive<Idx>where
Idx: PartialEq,
Sourceimpl<T> RangeBounds<T> for RangeToInclusive<T>
impl<T> RangeBounds<T> for RangeToInclusive<T>
1.26.0 (const: unstable) · Sourceimpl<T> SliceIndex<[T]> for RangeToInclusive<usize>
The methods index and index_mut panic if the end of the range is out of bounds.
impl<T> SliceIndex<[T]> for RangeToInclusive<usize>
The methods index and index_mut panic if the end of the range is out of bounds.
Sourcefn get(self, slice: &[T]) -> Option<&[T]>
fn get(self, slice: &[T]) -> Option<&[T]>
🔬This is a nightly-only experimental API. (
slice_index_methods)Returns a shared reference to the output at this location, if in
bounds.
Sourcefn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
fn get_mut(self, slice: &mut [T]) -> Option<&mut [T]>
🔬This is a nightly-only experimental API. (
slice_index_methods)Returns a mutable reference to the output at this location, if in
bounds.
Sourceunsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
unsafe fn get_unchecked(self, slice: *const [T]) -> *const [T]
🔬This is a nightly-only experimental API. (
slice_index_methods)Returns a pointer to the output at this location, without
performing any bounds checking. Read more
Sourceunsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
unsafe fn get_unchecked_mut(self, slice: *mut [T]) -> *mut [T]
🔬This is a nightly-only experimental API. (
slice_index_methods)Returns a mutable pointer to the output at this location, without
performing any bounds checking. Read more
impl<Idx> Copy for RangeToInclusive<Idx>where
Idx: Copy,
impl<Idx> Eq for RangeToInclusive<Idx>where
Idx: Eq,
impl<Idx> StructuralPartialEq for RangeToInclusive<Idx>